@@ -690,6 +690,11 @@ class VM(APIBase):
     def list_checkpoints(self):
         return self.vm.list_checkpoints()
 
+    @api.logged(on="api.virt")
+    @api.method
+    def dump_checkpoint(self, checkpoint_id):
+        return self.vm.dump_checkpoint(checkpoint_id)
+
     @api.logged(on="api.virt")
     @api.method
     def snapshot(self, snapDrives, snapMemory=None,
