@@ -1,4 +1,4 @@
-# Copyright 2011-2018 Red Hat, Inc.
+# Copyright 2011-2019 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ from __future__ import absolute_import
 from __future__ import division
 
 import glob
+import itertools
 import logging
 import os
 import re
@@ -41,8 +42,11 @@ from vdsm.network.link import sriov
 from vdsm.network.netinfo import nics, misc
 from vdsm.network.netinfo.cache import NetInfo
 from vdsm.network.netrestore import NETS_RESTORED_MARK
-from vdsm.network.netconfpersistence import RunningConfig, PersistentConfig, \
-    BaseConfig
+from vdsm.network.netconfpersistence import (
+    RunningConfig,
+    PersistentConfig,
+    BaseConfig,
+)
 from vdsm.network.nm import networkmanager
 
 # Ifcfg persistence restoration
@@ -57,9 +61,11 @@ _ALL_DEVICES_UP_TIMEOUT = 5
 
 def _get_sriov_devices():
     devices = hostdev.list_by_caps()
-    return [device_name for device_name, device_info
-            in six.viewitems(devices)
-            if 'totalvfs' in device_info['params']]
+    return [
+        device_name
+        for device_name, device_info in six.viewitems(devices)
+        if 'totalvfs' in device_info['params']
+    ]
 
 
 def _restore_sriov_config():
@@ -74,14 +80,17 @@ def _restore_sriov_config():
 
     non_persisted_devs = current_sriov_pci_devs - desired_sriov_pci_devs
     if non_persisted_devs:
-        logging.info('Non persisted SRIOV devices found: %s',
-                     non_persisted_devs)
+        logging.info(
+            'Non persisted SRIOV devices found: %s', non_persisted_devs
+        )
     missing_current_devs = desired_sriov_pci_devs - current_sriov_pci_devs
     if missing_current_devs:
-        logging.error('Persisted SRIOV devices could not be found: %s',
-                      missing_current_devs)
+        logging.error(
+            'Persisted SRIOV devices could not be found: %s',
+            missing_current_devs,
+        )
 
-    for sriov_devpci in (current_sriov_pci_devs & desired_sriov_pci_devs):
+    for sriov_devpci in current_sriov_pci_devs & desired_sriov_pci_devs:
         devname = sriov.pciaddr2devname(sriov_devpci)
         numvfs = persistent_config.devices[devname]['sriov']['numvfs']
         try:
@@ -90,7 +99,7 @@ def _restore_sriov_config():
             logging.exception(
                 'Restoring VF configuration for device %s failed. '
                 'Persisted nets built on this device will fail to restore.',
-                devname
+                devname,
             )
 
 
@@ -112,7 +121,10 @@ def unified_restoration():
     _verify_all_devices_are_up(list(_owned_ifcfg_files()))
 
     _wait_for_for_all_devices_up(
-        available_config.networks.keys() + available_config.bonds.keys())
+        itertools.chain(
+            available_config.networks.keys(), available_config.bonds.keys()
+        )
+    )
 
     if ipv6_supported():
         _restore_disable_ipv6()
@@ -121,7 +133,8 @@ def unified_restoration():
     setup_nets, setup_bonds, remove_nets, remove_bonds = classified_conf
 
     logging.info(
-        'Remove networks (%s) and bonds (%s).', remove_nets, remove_bonds)
+        'Remove networks (%s) and bonds (%s).', remove_nets, remove_bonds
+    )
     _greedy_setup_bonds(remove_bonds)
     _greedy_setup_nets(remove_nets)
 
@@ -129,7 +142,8 @@ def unified_restoration():
 
     _convert_to_blocking_dhcp(setup_nets)
     logging.info(
-        'Setup networks (%s) and bonds (%s).', setup_nets, setup_bonds)
+        'Setup networks (%s) and bonds (%s).', setup_nets, setup_bonds
+    )
     _greedy_setup_bonds(setup_bonds)
     _greedy_setup_nets(setup_nets)
 
@@ -138,8 +152,10 @@ def _greedy_setup_nets(setup_nets):
     for net, net_attr in six.iteritems(setup_nets):
         try:
             setupNetworks(
-                {net: net_attr}, {},
-                {'connectivityCheck': False, '_inRollback': True})
+                {net: net_attr},
+                {},
+                {'connectivityCheck': False, '_inRollback': True},
+            )
         except Exception:
             logging.exception('Failed to setup {}'.format(net))
 
@@ -148,8 +164,10 @@ def _greedy_setup_bonds(setup_bonds):
     for bond, bond_attr in six.iteritems(setup_bonds):
         try:
             setupNetworks(
-                {}, {bond: bond_attr},
-                {'connectivityCheck': False, '_inRollback': True})
+                {},
+                {bond: bond_attr},
+                {'connectivityCheck': False, '_inRollback': True},
+            )
         except Exception:
             logging.exception('Failed to setup {}'.format(bond))
 
@@ -161,7 +179,8 @@ def _verify_all_devices_are_up(owned_ifcfg_files):
     for ifcfg_file in owned_ifcfg_files:
         _upgrade_onboot(ifcfg_file)
     down_links = _get_links_with_state_down(
-        [os.path.basename(name) for name in owned_ifcfg_files])
+        [os.path.basename(name) for name in owned_ifcfg_files]
+    )
     if down_links:
         logging.debug("Some of the devices are down (%s).", down_links)
         ifcfg.start_devices(owned_ifcfg_files)
@@ -170,8 +189,9 @@ def _verify_all_devices_are_up(owned_ifcfg_files):
 def _upgrade_onboot(ifcfg_file):
     with open(ifcfg_file) as f:
         old_content = f.read()
-    new_content = re.sub('^ONBOOT=no$', 'ONBOOT=yes', old_content,
-                         flags=re.MULTILINE)
+    new_content = re.sub(
+        '^ONBOOT=no$', 'ONBOOT=yes', old_content, flags=re.MULTILINE
+    )
     if new_content != old_content:
         logging.debug("updating %s to ONBOOT=yes", ifcfg_file)
         with open(ifcfg_file, 'w') as f:
@@ -228,14 +248,16 @@ def _filter_available(persistent_config):
     present in the system"""
 
     available_nics = nics.nics()
-    available_bonds = _find_bonds_with_available_nics(available_nics,
-                                                      persistent_config.bonds)
+    available_bonds = _find_bonds_with_available_nics(
+        available_nics, persistent_config.bonds
+    )
 
     available_nets = _find_nets_with_available_devices(
         available_bonds,
         available_nics,
         persistent_config.bonds,
-        persistent_config.networks)
+        persistent_config.networks,
+    )
     return BaseConfig(available_nets, available_bonds, {})
 
 
@@ -250,18 +272,25 @@ def _classify_nets_bonds_config(persistent_config):
     desired_config = kernelconfig.normalize(persistent_config)
 
     changed_nets_names, extra_nets_names = _classify_entities_difference(
-        desired_config.networks, current_config.networks)
+        desired_config.networks, current_config.networks
+    )
 
     changed_bonds_names, extra_bonds_names = _classify_entities_difference(
-        desired_config.bonds, current_config.bonds)
+        desired_config.bonds, current_config.bonds
+    )
 
-    changed_nets = {net: persistent_config.networks[net]
-                    for net in changed_nets_names}
-    changed_bonds = {bond: persistent_config.bonds[bond]
-                     for bond in changed_bonds_names}
+    changed_nets = {
+        net: persistent_config.networks[net] for net in changed_nets_names
+    }
+    changed_bonds = {
+        bond: persistent_config.bonds[bond] for bond in changed_bonds_names
+    }
     extra_nets = {net: {'remove': True} for net in extra_nets_names}
-    extra_bonds = {bond: {'remove': True} for bond in extra_bonds_names
-                   if _owned_ifcfg(bond)}
+    extra_bonds = {
+        bond: {'remove': True}
+        for bond in extra_bonds_names
+        if _owned_ifcfg(bond)
+    }
 
     return changed_nets, changed_bonds, extra_nets, extra_bonds
 
@@ -273,40 +302,60 @@ def _classify_entities_difference(desired, current):
         current_attrs = current.get(name)
         if current_attrs != desired_attrs:
             changed_or_missing.add(name)
-            logging.info('%s is different or missing from persistent '
-                         'configuration. current: %s, persisted: %s',
-                         name, current_attrs, desired_attrs)
+            logging.info(
+                '%s is different or missing from persistent '
+                'configuration. current: %s, persisted: %s',
+                name,
+                current_attrs,
+                desired_attrs,
+            )
         else:
             unchanged.add(name)
-            logging.info('%s was not changed since last time it was persisted,'
-                         ' skipping restoration.', name)
+            logging.info(
+                '%s was not changed since last time it was persisted,'
+                ' skipping restoration.',
+                name,
+            )
     extra = set(current) - unchanged - changed_or_missing
     return changed_or_missing, extra
 
 
-def _find_nets_with_available_devices(available_bonds, available_nics,
-                                      persisted_bonds, persisted_nets):
+def _find_nets_with_available_devices(
+    available_bonds, available_nics, persisted_bonds, persisted_nets
+):
     available_nets = {}
     for net, attrs in six.viewitems(persisted_nets):
         bond = attrs.get('bonding')
         nic = attrs.get('nic')
         if bond is not None:
             if bond not in persisted_bonds:
-                logging.error('Bond "%s" is not persisted and will not be '
-                              'configured. Network "%s" will not be '
-                              'configured as a consequence', bond, net)
+                logging.error(
+                    'Bond "%s" is not persisted and will not be '
+                    'configured. Network "%s" will not be '
+                    'configured as a consequence',
+                    bond,
+                    net,
+                )
             elif bond not in available_bonds:
-                logging.error('Some of the nics required by bond "%s" (%s) '
-                              'are missing. Network "%s" will not be '
-                              'configured as a consequence', bond,
-                              persisted_bonds[bond]['nics'], net)
+                logging.error(
+                    'Some of the nics required by bond "%s" (%s) '
+                    'are missing. Network "%s" will not be '
+                    'configured as a consequence',
+                    bond,
+                    persisted_bonds[bond]['nics'],
+                    net,
+                )
             else:
                 available_nets[net] = attrs
 
         elif nic is not None:
             if nic not in available_nics:
-                logging.error('Nic "%s" required by network %s is missing. '
-                              'The network will not be configured', nic, net)
+                logging.error(
+                    'Nic "%s" required by network %s is missing. '
+                    'The network will not be configured',
+                    nic,
+                    net,
+                )
             else:
                 available_nets[net] = attrs
 
@@ -320,8 +369,9 @@ def _find_nets_with_available_devices(available_bonds, available_nics,
 def _find_bonds_with_available_nics(available_nics, persisted_bonds):
     available_bonds = {}
     for bond, attrs in six.viewitems(persisted_bonds):
-        available_bond_nics = [nic for nic in attrs['nics'] if
-                               nic in available_nics]
+        available_bond_nics = [
+            nic for nic in attrs['nics'] if nic in available_nics
+        ]
         if available_bond_nics:
             available_bonds[bond] = attrs.copy()
             available_bonds[bond]['nics'] = available_bond_nics
@@ -340,19 +390,24 @@ def _wait_for_for_all_devices_up(links):
         down_links = _get_links_with_state_down(links)
 
     if down_links:
-        logging.warning("Not all devices are up. VDSM might restore them "
-                        "although they were not changed since they were "
-                        "persisted.")
+        logging.warning(
+            "Not all devices are up. VDSM might restore them "
+            "although they were not changed since they were "
+            "persisted."
+        )
     else:
         logging.debug("All devices are up.")
 
 
 def _get_links_with_state_down(links):
-    return set(l.name for l in ipwrapper.getLinks() if
-               l.name in links and
-               _owned_ifcfg(l.name) and
-               _onboot_ifcfg(l.name) and
-               not l.oper_up)
+    return set(
+        l.name
+        for l in ipwrapper.getLinks()
+        if l.name in links
+        and _owned_ifcfg(l.name)
+        and _onboot_ifcfg(l.name)
+        and not l.oper_up
+    )
 
 
 def _ifcfg_dev_name(file_name):
@@ -363,6 +418,7 @@ def _ifcfg_dev_name(file_name):
 def _ipv6_ifcfg(link_name):
     def ipv6init(content):
         return all(line != 'IPV6INIT=no' for line in content.splitlines())
+
     return _ifcfg_predicate(link_name, ipv6init)
 
 
@@ -393,14 +449,15 @@ def _owned_ifcfg(link_name):
 
 def _onboot_ifcfg(link_name):
     predicate = lambda content: any(
-        line == 'ONBOOT=yes' for line in content.splitlines())
+        line == 'ONBOOT=yes' for line in content.splitlines()
+    )
     return _ifcfg_predicate(link_name, predicate)
 
 
 def _owned_ifcfg_content(content):
     return content.startswith(
-        '# Generated by VDSM version') or content.startswith(
-        '# automatically generated by vdsm')
+        '# Generated by VDSM version'
+    ) or content.startswith('# automatically generated by vdsm')
 
 
 def _ifcfg_predicate(link_name, predicate):
@@ -440,8 +497,9 @@ def restore(force):
             ifcfg_restoration()
             _copy_persistent_over_running_config()
     except Exception:
-        logging.exception('%s restoration failed.',
-                          'unified' if unified else 'ifcfg')
+        logging.exception(
+            '%s restoration failed.', 'unified' if unified else 'ifcfg'
+        )
         raise
     else:
         logging.info('restoration completed successfully.')
